%set_verify_elf_method unresolved=relaxed,textrel=relaxed
Name: serioussamclassic-vk
Summary: Serious Sam Classic native Linux version
License: GPL2
Version: 1.10.5
Release: alt2

Group: Games/Arcade
Url: https://github.com/tx00100xt/SeriousSamClassic-VK
Source: %name-%version.tar.gz
Source1: serioussam.png
Patch0: 0001-Fixed_Platform_definition.patch

BuildRequires: cmake libstdc++-devel-static rpm-macros-cmake sed flex bison
BuildRequires: zlib-devel libogg-devel libvorbis-devel glibc-devel nasm
BuildRequires: gcc-c++ python3-dev libSDL2-devel ImageMagick-tools libvulkan-devel
Requires: glibc libstdc++ zlib libogg libvorbis libSDL2 libvulkan1 vulkan-validation-layers awk sed
Conflicts: serioussamclassic 
ExclusiveArch: %ix86 %{arm} aarch64 x86_64 e2k

%description
Open source game engine version developed by Croteam for Serious Sam Classic (Windows, Linux, FreeBSD, Raspberry Pi OS)
Playing Serious Sam: The First and Second Encounter still requires a legitimate copy of
the game. You can purchase a copy from Steam or your favorite retailer.

Place .gro game files and Levels, Help folders from the Serious Sam installation to:
$HOME/.local/share/Serious-Engine/serioussam   - for Serious Sam: The First Encounter
$HOME/.local/share/Serious-Engine/serioussamse - for Serious Sam: The Second Encounter

%prep

%setup
%patch0 -p1

%build

# standart x86_64 build
%ifarch x86_64
echo "ALT Linux arch x86_64"
CMAKE_ARGS="-DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX:PATH=/usr"
echo "CMAKE_ARGS $CMAKE_ARGS"
%endif

# standart i586 build
%ifarch %ix86
echo "ALT Linux arch i586"
CMAKE_ARGS="-DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX:PATH=/usr -DCMAKE_C_FLAGS=-mmmx -DCMAKE_CXX_FLAGS=-mmmx -DUSE_I386_NASM_ASM=TRUE"
echo "CMAKE_ARGS $CMAKE_ARGS"
%endif

# for raspberry pi 3b/4
%ifarch aarch64
MODEL_PI=$(cat /proc/cpuinfo | grep Model)
if [[ $MODEL_PI = *"Raspberry Pi 4"* ]]; then echo $MODEL_PI;
CMAKE_ARGS="-DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX:PATH=/usr -DUSE_I386_NASM_ASM=FALSE -DRPI4=TRUE"
echo "CMAKE_ARGS $CMAKE_ARGS"
echo "Build for model Raspberry Pi4"
else
echo "CMAKE_ARGS $CMAKE_ARGS"
CMAKE_ARGS="-DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX:PATH=/usr -DUSE_I386_NASM_ASM=FALSE"
echo "Stadart aarch64 build"
fi
%endif

# e2k
%ifarch e2k
echo "ALT Linux arch e2k"
CMAKE_ARGS="-DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX:PATH=/usr"
echo "CMAKE_ARGS $CMAKE_ARGS"
%endif

NCPU=`cat /proc/cpuinfo |grep vendor_id |wc -l`

if [[ $NCPU -eq 0 ]]
then
  let NCPU='4'
else
  let NCPU=$NCPU
fi
echo "Cores: $NCPU"

find . -name "CMakeLists.txt" -exec sed -i 's/-march=native/-mtune=generic/g' {} +
rm -rf ./%_arch-alt2-linux
mkdir ./%_arch-alt2-linux
cd $_
cmake .. $CMAKE_ARGS
make -j$NCPU

%install
mkdir -p %buildroot%_desktopdir
mkdir -p %buildroot%_bindir
mkdir -p %buildroot%_libdir/serioussam
mkdir -p %buildroot%_libdir/serioussamse
mkdir -p %buildroot%_datadir/serioussam
mkdir -p %buildroot%_datadir/serioussamse

cat > %buildroot%_desktopdir/serioussam.desktop << EOF
[Desktop Entry]
Name=Serious Sam The First Encounter
Comment=Linux port of Serious Sam Classic The First Encounter
Exec=serioussam
TryExec=serioussam
Icon=serioussam.png
Terminal=false
Type=Application
Categories=Game;
EOF

cat > %buildroot%_desktopdir/serioussamse.desktop << EOF
[Desktop Entry]
Name=Serious Sam The Second Encounter
Comment=Linux port of Serious Sam Classic The Second Encounter
Exec=serioussamse
TryExec=serioussamse
Icon=serioussam.png
Terminal=false
Type=Application
Categories=Game;
EOF

# install menu icons
for N in 16 32 48 64 128;
do
convert %SOURCE1 -scale ${N}x${N} $N.png;
install -D -m 0644 $N.png %buildroot%_iconsdir/hicolor/${N}x${N}/apps/serioussam.png
done

install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/serioussam %buildroot%_bindir
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/serioussam-ded %buildroot%_bindir
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/serioussam-mkfont %buildroot%_bindir

install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/Debug/libEngine.so %buildroot%_libdir/
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/Debug/libGame.so %buildroot%_libdir/serioussam
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/Debug/libEntities.so %buildroot%_libdir/serioussam
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/Debug/libShaders.so %buildroot%_libdir/serioussam
install -D -m0755 ./%_arch-alt2-linux/SamTFE/Sources/Debug/libamp11lib.so %buildroot%_libdir/serioussam

install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/serioussamse %buildroot%_bindir
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/serioussamse-ded %buildroot%_bindir
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/serioussamse-mkfont %buildroot%_bindir

install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/Debug/libEngineMP.so %buildroot%_libdir/
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/Debug/libGameMP.so %buildroot%_libdir/serioussamse
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/Debug/libEntitiesMP.so %buildroot%_libdir/serioussamse
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/Debug/libShaders.so %buildroot%_libdir/serioussamse
install -D -m0755 ./%_arch-alt2-linux/SamTSE/Sources/Debug/libamp11lib.so %buildroot%_libdir/serioussamse

install -D -m0755 ./SamTFE/SE1_10b.gro %buildroot%_datadir/serioussam/
install -D -m0755 ./SamTFE/SE1_10b.gro %buildroot%_datadir/serioussamse/

%files

%_bindir/serioussam
%_bindir/serioussam-ded
%_bindir/serioussam-mkfont
%_bindir/serioussamse
%_bindir/serioussamse-ded
%_bindir/serioussamse-mkfont

%_libdir/libEngine.so
%_libdir/libEngineMP.so
%_libdir/serioussam/libGame.so
%_libdir/serioussam/libEntities.so
%_libdir/serioussam/libShaders.so
%_libdir/serioussam/libamp11lib.so
%_libdir/serioussamse/libGameMP.so
%_libdir/serioussamse/libEntitiesMP.so
%_libdir/serioussamse/libShaders.so
%_libdir/serioussamse/libamp11lib.so

%_datadir/serioussam/SE1_10b.gro
%_datadir/serioussamse/SE1_10b.gro

%_desktopdir/serioussam.desktop
%_desktopdir/serioussamse.desktop
%_iconsdir/hicolor/*/apps/serioussam.png

%post
update-desktop-database

%postun
update-desktop-database

%%changelog
* Mon Apr 24 2023 tx00100xt initial SPEC file.
- 
